==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QPropertyObserver_shell.cpp <==
#include "QPropertyObserver_shell.h"
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
QPropertyObserver_shell::QPropertyObserver_shell(QPropertyObserverBase::ChangeHandler changeHandler0)
    : QPropertyObserver(changeHandler0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPropertyObserver_shell::QPropertyObserver_shell(QPropertyObserverBase::ChangeHandler changeHandler0)", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->constructed(typeid(QPropertyObserver));
}

void __qt_construct_QPropertyObserver_with_ChangeHandler(void* __qtjambi_ptr, void (*changeHandler)(QPropertyObserver*, QUntypedPropertyData *))
{
    new(__qtjambi_ptr) QPropertyObserver_shell(changeHandler);
}

size_t sizeof_QPropertyObserver_shell(){
    return sizeof(QPropertyObserver_shell);
}

void deleter_QPropertyObserver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPropertyObserver")
    QPropertyObserver *_ptr = reinterpret_cast<QPropertyObserver *>(ptr);
    if(isShell){
        delete static_cast<QPropertyObserver_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QPropertyObserver_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyObserver_shell) ); }

jmethodID QPropertyObserver_shell::__shell_javaMethod(int pos) const { return QPropertyObserver_shell::__shell()->javaMethod(typeid(QPropertyObserver), pos); }

// emitting (writeShellConstructor)
QPropertyObserver_shell::QPropertyObserver_shell()
    : QPropertyObserver()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPropertyObserver::QPropertyObserver_shell()", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->constructed(typeid(QPropertyObserver));
}

QPropertyObserver_shell::QPropertyObserver_shell(QUntypedPropertyData* aliasedPropertyPtr0)
    : QPropertyObserver(aliasedPropertyPtr0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPropertyObserver::QPropertyObserver_shell(QUntypedPropertyData* aliasedPropertyPtr0)", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->constructed(typeid(QPropertyObserver));
}

// emitting (writeShellDestructor)
QPropertyObserver_shell::~QPropertyObserver_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPropertyObserver::~QPropertyObserver()", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->destructed(typeid(QPropertyObserver));
}

void QPropertyObserver_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyObserver_shell*>(ptr)->QPropertyObserver_shell::__shell()->tryDeleteShell(typeid(QPropertyObserver));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
jobject QPropertyObserver_access::__qt_aliasedProperty(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    QUntypedPropertyData* __qt_return_value = QPropertyObserver::aliasedProperty();
    return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyObserver()
void __qt_construct_QPropertyObserver_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyObserver()")
    Q_UNUSED(__java_arguments)
    QPropertyObserver *__qt_this = new(__qtjambi_ptr) QPropertyObserver_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QPropertyObserver(QUntypedPropertyData*)
void __qt_construct_QPropertyObserver_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyObserver(QUntypedPropertyData*)")
    jobject aliasedPropertyPtr0 = __java_arguments[0].l;
    QUntypedPropertyData* __qt_aliasedPropertyPtr0 = qtjambi_cast<QUntypedPropertyData* >(__jni_env, aliasedPropertyPtr0);
    QPropertyObserver *__qt_this = new(__qtjambi_ptr) QPropertyObserver_shell(__qt_aliasedPropertyPtr0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPropertyObserver_shell
void __qt_destruct_QPropertyObserver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPropertyObserver")
    reinterpret_cast<QPropertyObserver_shell*>(ptr)->~QPropertyObserver_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPropertyObserver::QPropertyObserver()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_initialize_1native__Lio_qt_core_QPropertyObserver_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyObserver::QPropertyObserver()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyObserver_0, sizeof(QPropertyObserver_shell), typeid(QPropertyObserver), true, &deleter_QPropertyObserver, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPropertyObserver::QPropertyObserver(QUntypedPropertyData*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_initialize_1native__Lio_qt_core_QPropertyObserver_2Lio_qt_core_QUntypedPropertyData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject aliasedPropertyPtr0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyObserver::QPropertyObserver(QUntypedPropertyData*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = aliasedPropertyPtr0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyObserver_1, sizeof(QPropertyObserver_shell), typeid(QPropertyObserver), true, &deleter_QPropertyObserver, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPropertyObserver::aliasedProperty()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_aliasedProperty_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyObserver *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyObserver::aliasedProperty()const", __qt_this)
        __java_return_value = static_cast<const QPropertyObserver_access*>(__qt_this)->__qt_aliasedProperty(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPropertyObserver::setSource(QtPrivate::QPropertyBindingData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_setSource_1native_1cref_1QtPrivate_1QPropertyBindingData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID property0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPropertyObserver *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyObserver::setSource(QtPrivate::QPropertyBindingData)", __qt_this)
        const QtPrivate::QPropertyBindingData& __qt_property0 = QtJambiAPI::objectReferenceFromNativeId<QtPrivate::QPropertyBindingData>(__jni_env, property0);
        __qt_this->setSource(__qt_property0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QPropertyObserver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPropertyObserver>("QPropertyObserver", "io/qt/core/QPropertyObserver");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPropertyObserver, {
        ConstructorInfo(&__qt_construct_QPropertyObserver_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPropertyObserver_1, "Lio/qt/core/QUntypedPropertyData;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPropertyObserver);
    registerSizeOfShell(typeId, sizeof(QPropertyObserver_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QPropertyObserver_shell.cpp <==
#include "QPropertyObserver_shell.h"
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
QPropertyObserver_shell::QPropertyObserver_shell(QPropertyObserverBase::ChangeHandler changeHandler0)
    : QPropertyObserver(changeHandler0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPropertyObserver_shell::QPropertyObserver_shell(QPropertyObserverBase::ChangeHandler changeHandler0)", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->constructed(typeid(QPropertyObserver));
}

void __qt_construct_QPropertyObserver_with_ChangeHandler(void* __qtjambi_ptr, void (*changeHandler)(QPropertyObserver*, QUntypedPropertyData *))
{
    new(__qtjambi_ptr) QPropertyObserver_shell(changeHandler);
}

size_t sizeof_QPropertyObserver_shell(){
    return sizeof(QPropertyObserver_shell);
}

void deleter_QPropertyObserver(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPropertyObserver")
    QPropertyObserver *_ptr = reinterpret_cast<QPropertyObserver *>(ptr);
    if(isShell){
        delete static_cast<QPropertyObserver_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QPropertyObserver_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyObserver_shell) ); }

jmethodID QPropertyObserver_shell::__shell_javaMethod(int pos) const { return QPropertyObserver_shell::__shell()->javaMethod(typeid(QPropertyObserver), pos); }

// emitting (writeShellConstructor)
QPropertyObserver_shell::QPropertyObserver_shell()
    : QPropertyObserver()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPropertyObserver::QPropertyObserver_shell()", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->constructed(typeid(QPropertyObserver));
}

QPropertyObserver_shell::QPropertyObserver_shell(QUntypedPropertyData* aliasedPropertyPtr0)
    : QPropertyObserver(aliasedPropertyPtr0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPropertyObserver::QPropertyObserver_shell(QUntypedPropertyData* aliasedPropertyPtr0)", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->constructed(typeid(QPropertyObserver));
}

// emitting (writeShellDestructor)
QPropertyObserver_shell::~QPropertyObserver_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPropertyObserver::~QPropertyObserver()", QPropertyObserver_shell::__shell())
    QPropertyObserver_shell::__shell()->destructed(typeid(QPropertyObserver));
}

void QPropertyObserver_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyObserver_shell*>(ptr)->QPropertyObserver_shell::__shell()->tryDeleteShell(typeid(QPropertyObserver));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
jobject QPropertyObserver_access::__qt_aliasedProperty_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    QUntypedPropertyData* __qt_return_value = QPropertyObserver::aliasedProperty();
    return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyObserver()
void __qt_construct_QPropertyObserver(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyObserver()")
    Q_UNUSED(__java_arguments)
    QPropertyObserver *__qt_this = new(__qtjambi_ptr) QPropertyObserver_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPropertyObserver::QPropertyObserver()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_initialize_1native__Lio_qt_core_QPropertyObserver_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyObserver::QPropertyObserver()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyObserver, sizeof(QPropertyObserver_shell), typeid(QPropertyObserver), true, &deleter_QPropertyObserver, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPropertyObserver(QUntypedPropertyData*)
void __qt_construct_QPropertyObserver_QUntypedPropertyData_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyObserver(QUntypedPropertyData*)")
    jobject aliasedPropertyPtr0 = __java_arguments[0].l;
    QUntypedPropertyData* __qt_aliasedPropertyPtr0 = qtjambi_cast<QUntypedPropertyData* >(__jni_env, aliasedPropertyPtr0);
    QPropertyObserver *__qt_this = new(__qtjambi_ptr) QPropertyObserver_shell(__qt_aliasedPropertyPtr0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPropertyObserver::QPropertyObserver(QUntypedPropertyData*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_initialize_1native__Lio_qt_core_QPropertyObserver_2Lio_qt_core_QUntypedPropertyData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject aliasedPropertyPtr0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPropertyObserver::QPropertyObserver(QUntypedPropertyData*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = aliasedPropertyPtr0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPropertyObserver_QUntypedPropertyData_ptr, sizeof(QPropertyObserver_shell), typeid(QPropertyObserver), true, &deleter_QPropertyObserver, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPropertyObserver_shell
void __qt_destruct_QPropertyObserver(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPropertyObserver")
    reinterpret_cast<QPropertyObserver_shell*>(ptr)->~QPropertyObserver_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPropertyObserver::aliasedProperty()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_aliasedProperty_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPropertyObserver *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyObserver::aliasedProperty()const", __qt_this)
        __java_return_value = static_cast<const QPropertyObserver_access*>(__qt_this)->__qt_aliasedProperty_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPropertyObserver::setSource(QtPrivate::QPropertyBindingData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QPropertyObserver_setSource_1native_1cref_1QtPrivate_1QPropertyBindingData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID property0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPropertyObserver *__qt_this = QtJambiAPI::objectFromNativeId<QPropertyObserver>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPropertyObserver::setSource(QtPrivate::QPropertyBindingData)", __qt_this)
        const QtPrivate::QPropertyBindingData& __qt_property0 = QtJambiAPI::objectReferenceFromNativeId<QtPrivate::QPropertyBindingData>(__jni_env, property0);
        __qt_this->setSource(__qt_property0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QPropertyObserver(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QPropertyObserver>("QPropertyObserver", "io/qt/core/QPropertyObserver");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPropertyObserver, {
        ConstructorInfo(&__qt_construct_QPropertyObserver, nullptr)
       ,ConstructorInfo(&__qt_construct_QPropertyObserver_QUntypedPropertyData_ptr, "Lio/qt/core/QUntypedPropertyData;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPropertyObserver);
    registerSizeOfShell(typeId, sizeof(QPropertyObserver_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
